Structs
- Commit
Receipt - The stable identifiers allocated for a committed session.
- Commit
Request - Everything needed to materialize one sealed session.
- Error
- Planned
Node - A node whose pending references will be resolved during commit.
Enums
Functions
- commit_
session - Atomically materializes a sealed session into one Kweb transaction.