Crate kcode_commit_session

Crate kcode_commit_session 

Structs

CommitReceipt
The stable identifiers allocated for a committed session.
CommitRequest
Everything needed to materialize one sealed session.
Error
PlannedNode
A node whose pending references will be resolved during commit.

Enums

ErrorKind

Functions

commit_session
Atomically materializes a sealed session into one Kweb transaction.